@@ -1,6 +1,6 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
-# Application Name - Health Check V0.5.2-4
+# Application Name - Health Check V0.5.2-5
 # Date 17 February 2010
 # Author - Greg Roberts (Noobmonkey @ Maemo Talk)
 # Contact - Me@Greg-roberts.com
@@ -238,7 +238,7 @@ class Ui_MainWindow(object):
         # box of some sort
         self.textBrowser = QtGui.QTextBrowser(self.tab_5)
         self.textBrowser.setGeometry(QtCore.QRect(0, 10, 781, 301))
-        self.textBrowser.setText (" Health Check V 0.5.2-4 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
+        self.textBrowser.setText (" Health Check V 0.5.2-5 \n Greg Roberts (Maemo.org - Noobmonkey) \n me@greg-roberts.com \n \n For Bugs and Feature requests: \n http://talk.maemo.org/showthread.php?p=541457")
         # Make the font small!!!
         font = QtGui.QFont()
         font.setPointSize(20)
@@ -334,7 +334,7 @@ class Ui_MainWindow(object):
         bus = dbus.SessionBus()
         proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
         interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
-        interface.Notify('HealthCheck', 0, './healthcheck.png', 'Sound Test', 'Stereo then Mono Test', [], {}, 3000)
+        interface.Notify('HealthCheck', 0, 'general_refresh', 'Sound Test', 'Stereo then Mono Test', [], {}, 3000)
         
         b = None
         b = os.popen('pacat --channels=2 /usr/share/sounds/ui-wake_up_tune.wav')
@@ -352,7 +352,7 @@ class Ui_MainWindow(object):
         bus = dbus.SessionBus()
         proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
         interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
-        interface.Notify('HealthCheck', 0, './healthcheck.png', 'Front Camera', 'Point your screen camera at a light.', [], {}, 3000)
+        interface.Notify('HealthCheck', 0, 'general_refresh', 'Front Camera', 'Point your screen camera at a light.', [], {}, 3000)
         # Close b - the greatly named variable - as i want to use it again! (Well close or declare it!)
         b = None
         # X-term - grab 10 buffered front camera images, and throw them into an image file.
@@ -369,7 +369,7 @@ class Ui_MainWindow(object):
         bus = dbus.SessionBus()
         proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
         interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
-        interface.Notify('HealthCheck', 0, './healthcheck.png', 'Back Camera', 'Open your Lens Cover!!.', [], {}, 3000)
+        interface.Notify('HealthCheck', 0, 'general_refresh', 'Back Camera', 'Open your Lens Cover!!.', [], {}, 3000)
         
         # Close b - the greatly named variable - as i want to use it again! (Well close or declare it!)
         b = None
@@ -451,6 +451,11 @@ class Ui_MainWindow(object):
         
         self.listWidget.addItem("N900 Board \t\t\t" + gb.strip())
 
+        gj = os.popen('cat /proc/cpuinfo | grep Revision').read()
+        gj = gj.strip()[11:]
+        
+        self.listWidget.addItem("N900 Board Revision \t" + gj.strip())
+
         gc = os.popen('locale | grep LANG').read()
         gc = gc.strip()[5:]
         
@@ -458,12 +463,18 @@ class Ui_MainWindow(object):
 
         gd = os.popen('cat /var/lib/dsme/boot_count').read()
         gd = gd.strip()
+        self.listWidget.addItem("Boot Count \t\t\t" + gd.strip())
 
         ge = os.popen('cat /sys/class/i2c-adapter/i2c-2/2-0063/power_level').read()
         ge = ge.strip()
     
         self.listWidget.addItem("FM Trans Strength \t\t" + ge.strip())
         
+    def updatenetname(self):
+        ga = os.popen('cat /etc/hostname').read()
+        ga = ga.strip()
+        self.listWidget2.addItem("Device Hostname \t" + ga.strip())
+
     def updateUptime(self):
         # This one reads fremantle version number (Firmware)
         ge = os.popen('uptime|cut -d" " -f4-|cut -d"," -f-1').read()
@@ -517,7 +528,7 @@ class Ui_MainWindow(object):
         bus = dbus.SessionBus()
         proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
         interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
-        interface.Notify('HealthCheck', 0, './healthcheck.png', 'Vibration TEST', 'Testing Vibrations', [], {}, 3000)
+        interface.Notify('HealthCheck', 0, 'general_refresh', 'Vibration TEST', 'Testing Vibrations', [], {}, 3000)
         # set f to = the accellerometer co-ordinates
         # the co-ords need to be pulled out and split for easy reading
         # Close down the co-ord file once used (Only displaying static info, not updating yet)
@@ -571,7 +582,7 @@ class Ui_MainWindow(object):
         bus = dbus.SessionBus()
         proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
         interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
-        interface.Notify('HealthCheck', 0, './healthcheck.png', 'LED TEST', 'Testing Power on, then SMS LED Patterns ', [], {}, 3000)
+        interface.Notify('HealthCheck', 0, 'general_refresh', 'LED TEST', 'Testing Power on, then SMS LED Patterns ', [], {}, 3000)
 
         bb = 'run-standalone.sh dbus-send --system --type=method_call --dest=com.nokia.mce /com/nokia/mce/request com.nokia.mce.request.req_led_pattern_activate string:' + "\'PatternPowerOn\'"
         b = os.popen(bb)
@@ -629,19 +640,26 @@ class Ui_MainWindow(object):
         self.pushButton_hw.setEnabled(False)
         self.pushButton_a1.setEnabled(False)
         self.pushButton_hw.setText(".")  
-        Thread(target=self.updaterootfs()).start()
+        #Thread(target=self.updaterootfs()).start()
+        self.updaterootfs()
         self.pushButton_hw.setText("..")
-        Thread(target=self.updateAccel()).start()
+        #Thread(target=self.updateAccel()).start()
+        self.updateAccel()
         self.pushButton_hw.setText("...")
-        Thread(target=self.updateCPU()).start()
+        #Thread(target=self.updateCPU()).start()
+        self.updateCPU()
         self.pushButton_hw.setText("....")
-        Thread(target=self.updatemydocs()).start()
+        #Thread(target=self.updatemydocs()).start()
+        self.updatemydocs()
         self.pushButton_hw.setText(".....")
-        Thread(target=self.updateMaemoV()).start()
+        self.updateMaemoV()
+        #Thread(target=self.updateMaemoV()).start()
         self.pushButton_hw.setText("......")
-        Thread(target=self.updateUptime()).start()
+        #Thread(target=self.updateUptime()).start()
+        self.updateUptime()
         self.pushButton_hw.setText(".......")
-        Thread(target=self.updateBatt()).start()
+        #Thread(target=self.updateBatt()).start()
+        self.updateBatt()
         self.pushButton_hw.setText("........")
         self.pushButton_hw.setText("Update Tab")
         self.pushButton_hw.setEnabled(True)
@@ -650,7 +668,7 @@ class Ui_MainWindow(object):
         bus = dbus.SessionBus()
         proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
         interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
-        interface.Notify('HealthCheck', 0, './healthcheck.png', 'System Tab', 'Finished Loading', [], {}, 2000)
+        interface.Notify('HealthCheck', 0, 'general_refresh', 'System Tab', 'Finished Loading', [], {}, 2000)
 
 
 
@@ -659,11 +677,14 @@ class Ui_MainWindow(object):
         self.pushButton_com.setEnabled(False)
         self.pushButton_a2.setEnabled(False)
         self.pushButton_com.setText("...")
-        Thread(target=self.updateGPS()).start()
+        #Thread(target=self.updateGPS()).start()
+        self.updateGPS()
         self.pushButton_com.setText(".....")
-        Thread(target=self.Cellular()).start()
+        #Thread(target=self.Cellular()).start()
+        self.Cellular()
         self.pushButton_com.setText("......")
-        
+        #Thread(target=self.updatenetname()).start()
+        self.updatenetname()
         self.pushButton_com.setText("Update Tab")
         self.pushButton_com.setEnabled(True)
         self.pushButton_a2.setEnabled(True)
@@ -671,25 +692,27 @@ class Ui_MainWindow(object):
         bus = dbus.SessionBus()
         proxy = bus.get_object('org.freedesktop.Notifications', '/org/freedesktop/Notifications')
         interface = dbus.Interface(proxy,dbus_interface='org.freedesktop.Notifications')
-        interface.Notify('HealthCheck', 0, './healthcheck.png', 'Comms Tab', 'Finished Loading', [], {}, 2000)
+        interface.Notify('HealthCheck', 0, 'general_refresh', 'Comms Tab', 'Finished Loading', [], {}, 2000)
 
     def updateTab3(self):
         self.pushButton_cam.setEnabled(False)
         self.pushButton_cam.setText("....")
-        Thread(target=self.updateImage()).start()
+        #Thread(target=self.updateImage()).start()
+        self.updateImage()
         self.pushButton_cam.setText("Front camera")
         self.pushButton_cam.setEnabled(True)
 
     def updateTab3a(self):
         self.pushButton_cam2.setEnabled(False)
         self.pushButton_cam2.setText("....")
-        Thread(target=self.updateImage2()).start()
+        #Thread(target=self.updateImage2()).start()
+        self.updateImage2()
         self.pushButton_cam2.setText("Back Camera")
         self.pushButton_cam2.setEnabled(True)
         
     # This is the start of the QT Designer translation function - not using the translation function, but left it in, to show it is part of the class   
     def retranslateUi(self, MainWindow):
-        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.2-4", None, QtGui.QApplication.UnicodeUTF8))
+        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "Health Check 0.5.2-5", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab), QtGui.QApplication.translate("MainWindow", "System", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_2), QtGui.QApplication.translate("MainWindow", "Comms", None, QtGui.QApplication.UnicodeUTF8))
         self.tabWidget.setTabText(self.tabWidget.indexOf(self.tab_3), QtGui.QApplication.translate("MainWindow", "Camera", None, QtGui.QApplication.UnicodeUTF8))
